#!/usr/bin/env python3

from datetime import datetime
from requests import get
from subprocess import check_output
from sys import exit


# bundlewrap.utils.text.format_duration, but trimmed down
def format_time(seconds):
    if seconds is None:
        return "?"
    seconds = int(seconds)
    components = []
    if seconds >= 3600:
        hours = int(seconds / 3600)
        seconds -= hours * 3600
        components.append('{}h'.format(hours))
    if seconds >= 60:
        minutes = int(seconds / 60)
        seconds -= minutes * 60
        components.append('{}m'.format(minutes))
    if not components:
        components.append('now')
    return " ".join(components)


try:
    wifi_ssid = check_output("iw dev wlp4s0 link | awk '/SSID/ {print $2}'", shell=True).decode().strip().lower()

    if wifi_ssid not in (
        'wifi@db',
        'wifionice'
    ):
        exit(0)

    now = datetime.now()

    trip_info_req = get('https://iceportal.de/api1/rs/tripInfo/trip')
    trip_info_req.raise_for_status()
    trip_info = trip_info_req.json()['trip']

    ice_status_req = get('https://iceportal.de/api1/rs/status')
    ice_status_req.raise_for_status()
    ice_status = ice_status_req.json()

    next_stop_id = trip_info['stopInfo']['actualNext']
    for stop in trip_info['stops']:
        if stop['station']['evaNr'] == next_stop_id:
            if stop['timetable']['departureDelay']:
                delay = ' | <span color="#FF0000">{}</span>'.format(stop['timetable']['departureDelay'])
            else:
                delay = ''

            arrival = datetime.fromtimestamp(stop['timetable']['actualArrivalTime']/1000)
            arrival_in = arrival - now

            next_stop = '{} <span color="#999999">[{}]</span> {} ({}{})'.format(
                stop['station']['name'],
                stop['track']['actual'],
                arrival.strftime('%H:%M'),
                format_time(arrival_in.total_seconds()),
                delay
            )
            break
    else:
        next_stop = 'Endstation, bitte Aussteigen'

    print('<span color="#999999">{}km/h</span> > {} <span color="#999999">(Net: {} > [{}] {})</span>'.format(
        ice_status['speed'],
        next_stop,
        ice_status['connectivity']['currentState'],
        format_time(ice_status['connectivity']['remainingTimeSeconds']),
        ice_status['connectivity']['nextState'],
    ))
except Exception as e:
    print(repr(e))
    exit(0)
